// import { objectPattern } from '@babel/types';
import '@wisdom-utils/utils/lib/logger';
import _ from 'lodash';
import {
  addGlobalUncaughtErrorHandler,
  registerMicroApps,
  runAfterFirstMounted,
  setDefaultMountApp,
  start,
} from 'qiankun';
import { event, store as microStore } from '@wisdom-utils/utils';
import micorConfig, { genActiveRule } from '../config/micor';
import { actionCreators } from './containers/App/store';
import loader from './render';
import store from './stores';
import actions from './actions';
import { processComponentName } from './utils/utils';

// eslint-disable-next-line no-undef
const Logger = logger('micro');

export const initMicroApps = () => {

  /* eslint-disable */
    const config = window.globalConfig || {};
    //createStoreage.get('globalConfig');
    const application = config && config.products || [];
    let products = [];


    application && Array.isArray(application) && application.length > 0 && application.map(item => {
        if (item.PackageName === 'report') {
            products.push({
                name: item.PackageName,
                entry: item.RouteUrl,
                container: '#micro-container',
                activeRule: genActiveRule(`/civbase/${item.PackageName}`),
                props: {
                    ...item.DefaultSetting,
                    routerBase: item.PackageName,
                    event: event,
                    store: microStore
                }
            })
        } else {
            products.push({
                name: item.PackageName,
                entry: window.location.protocol + "//" + window.location.host + (`/${item.PackageName}`),
                container: '#micro-container',
                activeRule: genActiveRule(`/civbase/${item.PackageName}`),
                props: {
                    ...item.DefaultSetting,
                    routerBase: item.PackageName,
                    event: event,
                    store: microStore
                }
            })
        }

    });
    const entrys =
        process.env.NODE_ENV !== 'production' ?
            micorConfig.dev :
            products;

    registerMicroApps(
        entrys.map(item => {
            item.loader = loader;
            item.props = {
                emitter: window.share.event,
                baseRoot: item.name,
                event: event,
                store: microStore,
                // eslint-
                // disable-next-line no-undef
                globalConfig: /civweb4/.test(item.name) ? Object.assign({}, config, {
                    homepage: config.homepage ? config.homepage.replace(/civweb\//, '') : config.homepage
                }) : config,
                //createStoreage.get('globalConfig'),
                XMLHttpRequest: window.XMLHttpRequest,
            };
            return item;
        }), {
        beforeLoad: [
            app => {
                store.dispatch(actionCreators.updateMicroMounted(true));
                Logger.info('[LifeCycle] before load %c%s');
            },
        ],
        beforeMount: [
            app => {
                Logger.info(`[LifeCycle] before mount %c%s ${app.name}`);
            },
        ],
        afterMount: [
            app => {
                store.dispatch(actionCreators.updateMicroMounted(false));
                Logger.info(`[LifeCycle] after mount %c%s ${app.name}`);
            },
        ],
        beforeUnmount: [
            app => {
                window.share.event.removeAllListeners('changeRoute');
                Logger.info(`[LifeCycle] after unmount %c%s ${app.name}`);
                // window.globalConfig = {}
                // createStoreage.remove(`__PANDA_STORE__${location.hostname}`)
            },
        ],
        afterUnmount: [app => { }],
    },
    );
    const globalStore = store.getState().toJS();
    const globalConfig = window.globalConfig;
    // globalConfig.homepage = globalConfig.homepage && /civweb4/.test(globalConfig.homepage) ? config.homepage.replace(/civweb4\//, ''): globalConfig.homepage;
    actions.setGlobalState({
        // eslint-disable-next-line no-undef
        globalConfig: globalConfig
        //createStoreage.get('globalConfig'),
    });

    microStore.set("props:globalConfig", {
        globalConfig: globalConfig,
        global: globalStore.global
    });
    start({
        sandbox: {
            experimentalStyleIsolation: false,
            loose: true,
        },
        singular: false,
        scopedCSS: true,
        prefetch: 'all',
        // eslint-disable-next-line no-underscore-dangle
        // getPublicPath: window.__INJECTED_PUBLIC_PATH_BY_QIANKUN__,
        excludeAssetFilter: url =>
            url.indexOf('framework/highcharts') !== -1 ||
            // url.indexOf('framework/amap/AMap.UI') !== -1 ||
            // url.indexOf('framework/amap/init.js') !== -1 ||
            url.indexOf('jquery') !== -1 ||
            url.indexOf('components/filetools/xlsx.core.min') !== -1 ||
            url.indexOf('managers/MapManager.js') !== -1 ||
            url.indexOf('jquery.mCustomScrollbar.js') !== -1 ||
            url.indexOf('QIAN_KUN_Platform.js') !== -1 ||
            url.indexOf('configuration/js') !== -1 ||
            url.indexOf('framework/three.js') !== -1 ||
            url.indexOf('threedimensional/frameworkthree') !== -1 ||
            url.indexOf('iframe/Civ3DLLab/js') !== -1 ||
            url.indexOf('framework/jquery/gridify-min.js') !== -1 ||
            url.indexOf('framework/jquery/gridify.qrcode.js') !== -1 ||
            url.indexOf('framework/application/Platform.js') !== -1 ||
            url.indexOf('webgisPanda/AMapTool') !== -1 ||
            url.indexOf('framework/underscore') !== -1 ||
            url.indexOf('echarts') !== -1 ||
            url.indexOf('lbs.amap.com') !== -1 ||
            url.indexOf('restapi.amap.com') !== -1 ||
            url.indexOf('webapi.amap.com') !== -1 ||
            url.indexOf('webapi.amap.com/count') !== -1 ||
            url.indexOf('webapi.amap.com/maps') !== -1 ||
            url.indexOf('restapi.amap.com/v3') !== -1 ||
            url.indexOf('api.map.baidu.com') !== -1 ||
            url.indexOf('map.baidu.com') !== -1 ||
            url.indexOf('pv.sohu.com') !== -1 ||
            url.indexOf('mt0.google.cn') !== -1 ||
            url.indexOf('mt1.google.cn') !== -1 ||
            url.indexOf('mt2.google.cn') !== -1 ||
            url.indexOf('mt3.google.cn') !== -1 ||
            url.indexOf('hm.baidu.com') !== -1 ||
            url.indexOf('framework/antv/antvL7.min.js') !== -1 ||
            url.indexOf('https://maponline0.bdimg.com') !== -1 ||
            url.indexOf('https://maponline1.bdimg.com') !== -1 ||
            url.indexOf('https://maponline2.bdimg.com') !== -1 ||
            url.indexOf('https://maponline3.bdimg.com') !== -1 ||
            url.indexOf('https://api.map.baidu.com/getscript') !== -1,
    });
    runAfterFirstMounted(() => {
        Logger.info('[MainApp] first app mounted');
    });
    // eslint-disable-next-line no-use-before-define
    defaultApp();
    addGlobalUncaughtErrorHandler(event => {

        console.log(event);

    });
};

export const defaultApp = () => {

    // eslint-disable-next-line no-undef
    const config = window.globalConfig;

    if (config && config.token) {

        // const basePath =config.homepage !== '' && FILTER_FOLER_REG.test(config.homepage) ?'civweb4' :'civweb4';
        // if(config && config.home) {
        //     setDefaultMountApp(`/civbase/${config.home.path.replace(/^\//, '')}`);
        // } else {

        //     const homepage = _.isNull(config.homepage) ? '/index': '/' + config.homepage;
        //     setDefaultMountApp(`/${pkg.name.toLocaleLowerCase()}/${basePath}${homepage}`);
        //     createStoreage.set('init_web4', true)
        // }
        // let homepage = config.homepage.replace('civweb4/', '');
        let url = !config.home ? ((config.homepage === '' || _.isNull(config.homepage)) ? `/civbase/civweb4`: `/civbase/civweb4/${config.homepage.replace(/^\//, '').replace(/^civweb4\//, '')}`) :  `/civbase/${config.homepage.replace(/^\//, '')}`;
        /**
         * issue 处理监听路由规则
         */
        // if(url === '/civbase/civweb4/') {
        //     url = url.replace(/civweb4\//, 'civweb4');
        // }

        setDefaultMountApp(url);
        // if(config.homepage.indexOf('civweb4') > -1) createStoreage.set('init_web4', true);
    }
};

// const AntdComponentMap = ['affix', 'alert', 'anchor', 'auto-complete', 'avatar', 'backtop', 'badge', 'breadcrumb', 'button', 'calendar', 'card', 'carousel', 'cascader', 'checkbox', 'col', 'collapse', 'comment', 'config-provider', 'date-picker', 'descriptions', 'divider', 'drawer', 'dropdown', 'empty', 'form', 'grid', 'icon', 'image', 'input', 'input-number', 'layout', 'list', 'local-provider', 'mentions', 'menu', 'message', 'modal', 'notification', 'page-header', 'pagination', 'popconfirm', 'popover', 'progress', 'radio', 'rate', 'result', 'row', 'select', 'skeleton', 'slider', 'space', 'spin', 'statistic', 'steps', 'switch', 'table', 'tabs', 'tag', 'time-picker', 'timeline', 'tooltip', 'transfer', 'tree', 'tree-select', 'typography', 'upload', 'version']

/**
 * window.app主要功能：
   define 定义项目的公共库，主要用来解决JS公共库的管理问题
   require 引用自己的定义的基础库，配合define来使用
   routes 用于存放全局的路由，子项目路由添加到window.app.routes，用于完成路由的注册
   init 注册入口，为子项目添加上namesapce标识，注册上子项目管理数据流的reducers
 */

window.app = {

    modules: {},
    require: function (request, method) {

        if (request !== '.' && this.modules[request]) {
            return _.isFunction(this.modules[request]) ? this.modules[request]() : _.isFunction(this.modules[request][method]) && this.modules[request][method]();
        }
        if (request === '.') {
            return
        }
        /**
         * 特殊处理antd
         */
        if(request.indexOf('antd') > -1) {
            const modules = this.modules['antd']();
            const r = request.split('/');
            const pkg = r[2];
            if(r.length >3) {
                const m = request.split('/')
                const styles = this.modules[m.join('-')];
                if(styles) {
                    if(r[3] === 'style') {
                        return styles['index.js'] && styles['index.js']();
                    }
                    return styles[r[3]] && styles[r[3]]();
                }
                return
            }
            const componentName = processComponentName(pkg, {
                firstUpperCase: pkg === 'message' || pkg === 'notification' ? false: true
            });

            return modules[componentName];
        }

        if(request.indexOf(method) > -1) {
            request = request.replace(method, '').replace(/\//, '')
            return _.isFunction(this.modules[request]) && this.modules[request]();
        }
        return _.isFunction(this.modules[request]) && this.modules[request]();
    },
    define: function (name, context, index) {

        let keys = context.keys();
        for (let key of keys) {
            let parts = name.indexOf('@') > -1 ? [name, ...(key.slice(1).split('/'))] : (name + key.slice(1)).split('/');
            parts = parts.filter(item => item !== "");
            let dir = this.modules;
            for (let i = 0; i < parts.length - 1; i++) {
                let part = parts[i];
                if (!dir.hasOwnProperty(part)) {
                    dir[part] = {};
                }
                dir = dir[part];
            }
            dir[parts[parts.length - 1]] = context.bind(context, key);
        }
        if (index && index !== null) {

            this.modules[name] = this.modules[name][index];
        }
    },
    init: function (namespace, reducers) {
        [namespace] = reducers;
    }
};


// window.app.define('city-data', require.context('./components/CitySelector', true, /^.\/(CitySelector\/)?[^\/]+\.js$/), 'city-data.js')
window.app.define('react', require.context('react', true, /^.\/index\.js$/), 'index.js');
window.app.define('react-dom', require.context('react-dom', true, /^.\/index\.js$/), 'index.js');
window.app.define('react-router', require.context('react-router', true, /^.\/index\.js$/), 'index.js');
window.app.define('lodash', require.context('lodash', true, /^.\/index\.js$/), 'index.js');
window.app.define('connected-react-router', require.context('../node_modules/connected-react-router/lib', true, /^.\/(lib\/)?[^\/]+\.js$/), 'index.js');
// window.app.define('connected-react-router/immutable', require.context('../node_modules/connected-react-router/lib', true, /^.\/(lib\/)?[^\/]+\.js$/), 'immutable.js')
window.app.define('react-helmet', require.context('../node_modules/react-helmet/lib', true, /^.\/(lib\/)?[^\/]+\.js$/), 'Helmet.js');
window.app.define('qrcode.react', require.context('../node_modules/qrcode.react/lib', true, /^.\/(lib\/)?[^\/]+\.js$/), 'index.js');
window.app.define('qr.js', require.context('qr.js', true, /^.\/index\.js$/), 'index.js');
window.app.define('query-string', require.context('query-string', true, /^.\/index\.js$/), 'index.js');
window.app.define('react-helmet-async', require.context('../node_modules/react-helmet-async/lib', true, /^.\/(lib\/)?[^\/]+\.js$/), 'index.js');
window.app.define('immutable', require.context('../node_modules/immutable/dist', true, /^.\/(dist\/)?[^\/]+\.js$/), 'immutable.min.js');
window.app.define('redux-immutable', require.context('../node_modules/redux-immutable/dist', true, /^.\/(dist\/)?[^\/]+\.js$/), 'index.js');
window.app.define('redux-logger', require.context('../node_modules/redux-logger/dist', true, /^.\/(dist\/)?[^\/]+\.js$/), 'redux-logger.js');

window.app.define('react-router-dom', require.context('react-router-dom', true, /^.\/index\.js$/), 'index.js');
window.app.define('react-redux', require.context('../node_modules/react-redux/dist', true, /^.\/(dist\/)?[^\/]+\.js$/), 'react-redux.min.js');
window.app.define('redux', require.context('../node_modules/redux/dist', true, /^.\/(dist\/)?[^\/]+\.js$/), 'redux.min.js');
window.app.define('mqtt-client', require.context('../node_modules/mqtt-client/lib', true, /^.\/(lib\/)?[^\/]+\.js$/), 'index.js');
window.app.define('kit_logger', require.context('../node_modules/kit_logger/lib', true, /^.\/(lib\/)?[^\/]+\.js$/), 'index.js');
window.app.define('kit_utils', require.context('../node_modules/kit_utils/lib', true, /^.\/(lib\/)?[^\/]+\.js$/));
window.app.define('kit_global_config', require.context('../node_modules/kit_global_config/lib', true, /^.\/(lib\/)?[^\/]+\.js$/), 'index.js');
window.app.define('@wisdom-utils/utils', require.context('../node_modules/@wisdom-utils/utils/lib', true, /^.\/(lib\/)?[^\/]+\.js$/), 'index.js');
window.app.define('@wisdom-utils/runtime', require.context('../node_modules/@wisdom-utils/runtime/lib', true, /^.\/(lib\/)?[^\/]+\.js$/), 'index.js');
window.app.define('@wisdom-utils/components', require.context('../node_modules/@wisdom-utils/components/lib', true, /^.\/(lib\/)?[^\/]+\.js$/), 'index.js');

/**
 * arcgismap
 */
 window.app.define('@wisdom-map/arcgismap', require.context('../node_modules/@wisdom-map/arcgismap/lib', true, /^.\/(lib\/)?[^\/]+\.js$/), 'index.js');
 window.app.define('@wisdom-map/arcgisMap', require.context('../node_modules/@wisdom-map/arcgisMap/lib', true, /^.\/(lib\/)?[^\/]+\.js$/), 'index.js');
 window.app.define('@wisdom-map/Amap', require.context('../node_modules/@wisdom-map/Amap/lib', true, /^.\/(lib\/)?[^\/]+\.js$/), 'index.js');
 window.app.define('@wisdom-map/Map', require.context('../node_modules/@wisdom-map/Map/lib', true, /^.\/(lib\/)?[^\/]+\.js$/), 'index.js');

// window.app.define('@wisdom-map/arcgismap', require.context('../node_modules/@wisdom-map/arcgismap/lib', true, /^.\/(lib\/)?[^\/]+\.js$/), 'index.js');
// // window.app.define('@wisdom-map/arcgismap/lib/widgets', require.context('../node_modules/@wisdom-map/arcgismap/lib/widgets', true, /^.\/(lib\/)?[^\/]+\.js$/));
// window.app.define('@wisdom-map/arcgismap/lib/arcgisapi/4.20/@arcgis/core', require.context('../node_modules/@wisdom-map/arcgismap/lib/arcgisapi/4.20/@arcgis/core', true, /^.\/(arcgisapi\/)?[^\/]+\.js$/));
// window.app.define('@wisdom-map/arcgismap/lib/arcgisapi/4.20/@arcgis/core/chunks', require.context('../node_modules/@wisdom-map/arcgismap/lib/arcgisapi/4.20/@arcgis/core/chunks', true, /^.\/(arcgisapi\/)?[^\/]+\.js$/));
// window.app.define('@wisdom-map/arcgismap/lib/arcgisapi/4.20/@arcgis/core/core', require.context('../node_modules/@wisdom-map/arcgismap/lib/arcgisapi/4.20/@arcgis/core/core', true, /^.\/(arcgisapi\/)?[^\/]+\.js$/));
// window.app.define('@wisdom-map/arcgismap/lib/arcgisapi/4.20/@arcgis/core/core/accessorSupport', require.context('../node_modules/@wisdom-map/arcgismap/lib/arcgisapi/4.20/@arcgis/core/core/accessorSupport', true, /^.\/(arcgisapi\/)?[^\/]+\.js$/));
// window.app.define('@wisdom-map/arcgismap/lib/arcgisapi/4.20/@arcgis/core/core/accessorSupport/decorators', require.context('../node_modules/@wisdom-map/arcgismap/lib/arcgisapi/4.20/@arcgis/core/core/accessorSupport/decorators', true, /^.\/(arcgisapi\/)?[^\/]+\.js$/));
// window.app.define('@wisdom-map/arcgismap/lib/arcgisapi/4.20/@arcgis/core/core/sql', require.context('../node_modules/@wisdom-map/arcgismap/lib/arcgisapi/4.20/@arcgis/core/core/sql', true, /^.\/(arcgisapi\/)?[^\/]+\.js$/));
// window.app.define('@wisdom-map/arcgismap/lib/arcgisapi/4.20/@arcgis/core/core/workers', require.context('../node_modules/@wisdom-map/arcgismap/lib/arcgisapi/4.20/@arcgis/core/core/workers', true, /^.\/(arcgisapi\/)?[^\/]+\.js$/));

// window.app.define('@wisdom-map/arcgismap/lib/arcgisapi/4.20/@arcgis/core/form', require.context('../node_modules/@wisdom-map/arcgismap/lib/arcgisapi/4.20/@arcgis/core/form', true, /^.\/(arcgisapi\/)?[^\/]+\.js$/));
// window.app.define('@wisdom-map/arcgismap/lib/arcgisapi/4.20/@arcgis/core/geometry', require.context('../node_modules/@wisdom-map/arcgismap/lib/arcgisapi/4.20/@arcgis/core/geometry', true, /^.\/(arcgisapi\/)?[^\/]+\.js$/));
// window.app.define('@wisdom-map/arcgismap/lib/arcgisapi/4.20/@arcgis/core/geometry/support', require.context('../node_modules/@wisdom-map/arcgismap/lib/arcgisapi/4.20/@arcgis/core/geometry/support', true, /^.\/(arcgisapi\/)?[^\/]+\.js$/));
// window.app.define('@wisdom-map/arcgismap/lib/arcgisapi/4.20/@arcgis/core/identity', require.context('../node_modules/@wisdom-map/arcgismap/lib/arcgisapi/4.20/@arcgis/core/identity', true, /^.\/(arcgisapi\/)?[^\/]+\.js$/));
// window.app.define('@wisdom-map/arcgismap/lib/arcgisapi/4.20/@arcgis/core/layers', require.context('../node_modules/@wisdom-map/arcgismap/lib/arcgisapi/4.20/@arcgis/core/layers', true, /^.\/(arcgisapi\/)?[^\/]+\.js$/));

// window.app.define('@wisdom-map/arcgismap/lib/arcgisapi/4.20/@arcgis/core/layers/buildingSublayers', require.context('../node_modules/@wisdom-map/arcgismap/lib/arcgisapi/4.20/@arcgis/core/layers/buildingSublayers', true, /^.\/(arcgisapi\/)?[^\/]+\.js$/));
// window.app.define('@wisdom-map/arcgismap/lib/arcgisapi/4.20/@arcgis/core/layers/ogc', require.context('../node_modules/@wisdom-map/arcgismap/lib/arcgisapi/4.20/@arcgis/core/layers/ogc', true, /^.\/(arcgisapi\/)?[^\/]+\.js$/));
// window.app.define('@wisdom-map/arcgismap/lib/arcgisapi/4.20/@arcgis/core/layers/pointCloudFilters', require.context('../node_modules/@wisdom-map/arcgismap/lib/arcgisapi/4.20/@arcgis/core/layers/pointCloudFilters', true, /^.\/(arcgisapi\/)?[^\/]+\.js$/));
// window.app.define('@wisdom-map/arcgismap/lib/arcgisapi/4.20/@arcgis/core/layers/support', require.context('../node_modules/@wisdom-map/arcgismap/lib/arcgisapi/4.20/@arcgis/core/layers/support', true, /^.\/(arcgisapi\/)?[^\/]+\.js$/));

// window.app.define('@wisdom-map/arcgismap/lib/arcgisapi/4.20/@arcgis/core/networks', require.context('../node_modules/@wisdom-map/arcgismap/lib/arcgisapi/4.20/@arcgis/core/networks', true, /^.\/(arcgisapi\/)?[^\/]+\.js$/));
// window.app.define('@wisdom-map/arcgismap/lib/arcgisapi/4.20/@arcgis/core/networks/support', require.context('../node_modules/@wisdom-map/arcgismap/lib/arcgisapi/4.20/@arcgis/core/networks/support', true, /^.\/(arcgisapi\/)?[^\/]+\.js$/));

// window.app.define('@wisdom-map/arcgismap/lib/arcgisapi/4.20/@arcgis/core/popup', require.context('../node_modules/@wisdom-map/arcgismap/lib/arcgisapi/4.20/@arcgis/core/popup', true, /^.\/(arcgisapi\/)?[^\/]+\.js$/));
// window.app.define('@wisdom-map/arcgismap/lib/arcgisapi/4.20/@arcgis/core/popup/support', require.context('../node_modules/@wisdom-map/arcgismap/lib/arcgisapi/4.20/@arcgis/core/popup/support', true, /^.\/(arcgisapi\/)?[^\/]+\.js$/));
// window.app.define('@wisdom-map/arcgismap/lib/arcgisapi/4.20/@arcgis/core/popup/content', require.context('../node_modules/@wisdom-map/arcgismap/lib/arcgisapi/4.20/@arcgis/core/popup/content', true, /^.\/(arcgisapi\/)?[^\/]+\.js$/));
// window.app.define('@wisdom-map/arcgismap/lib/arcgisapi/4.20/@arcgis/core/popup/content/support', require.context('../node_modules/@wisdom-map/arcgismap/lib/arcgisapi/4.20/@arcgis/core/popup/content/support', true, /^.\/(arcgisapi\/)?[^\/]+\.js$/));

// window.app.define('@wisdom-map/arcgismap/lib/arcgisapi/4.20/@arcgis/core/portal', require.context('../node_modules/@wisdom-map/arcgismap/lib/arcgisapi/4.20/@arcgis/core/portal', true, /^.\/(arcgisapi\/)?[^\/]+\.js$/));

// window.app.define('@wisdom-map/arcgismap/lib/arcgisapi/4.20/@arcgis/core/renderers', require.context('../node_modules/@wisdom-map/arcgismap/lib/arcgisapi/4.20/@arcgis/core/renderers', true, /^.\/(arcgisapi\/)?[^\/]+\.js$/));
// window.app.define('@wisdom-map/arcgismap/lib/arcgisapi/4.20/@arcgis/core/renderers/support', require.context('../node_modules/@wisdom-map/arcgismap/lib/arcgisapi/4.20/@arcgis/core/renderers/support', true, /^.\/(arcgisapi\/)?[^\/]+\.js$/));
// window.app.define('@wisdom-map/arcgismap/lib/arcgisapi/4.20/@arcgis/core/renderers/visualVariables', require.context('../node_modules/@wisdom-map/arcgismap/lib/arcgisapi/4.20/@arcgis/core/renderers/visualVariables', true, /^.\/(arcgisapi\/)?[^\/]+\.js$/));
// window.app.define('@wisdom-map/arcgismap/lib/arcgisapi/4.20/@arcgis/core/renderers/visualVariables/support', require.context('../node_modules/@wisdom-map/arcgismap/lib/arcgisapi/4.20/@arcgis/core/renderers/visualVariables/support', true, /^.\/(arcgisapi\/)?[^\/]+\.js$/));


// window.app.define('@wisdom-map/arcgismap/lib/arcgisapi/4.20/@arcgis/core/rest', require.context('../node_modules/@wisdom-map/arcgismap/lib/arcgisapi/4.20/@arcgis/core/rest', true, /^.\/(arcgisapi\/)?[^\/]+\.js$/));
// window.app.define('@wisdom-map/arcgismap/lib/arcgisapi/4.20/@arcgis/core/rest/geoprocessor', require.context('../node_modules/@wisdom-map/arcgismap/lib/arcgisapi/4.20/@arcgis/core/rest/geoprocessor', true, /^.\/(arcgisapi\/)?[^\/]+\.js$/));
// window.app.define('@wisdom-map/arcgismap/lib/arcgisapi/4.20/@arcgis/core/rest/networks', require.context('../node_modules/@wisdom-map/arcgismap/lib/arcgisapi/4.20/@arcgis/core/rest/networks', true, /^.\/(arcgisapi\/)?[^\/]+\.js$/));
// window.app.define('@wisdom-map/arcgismap/lib/arcgisapi/4.20/@arcgis/core/rest/networks/support', require.context('../node_modules/@wisdom-map/arcgismap/lib/arcgisapi/4.20/@arcgis/core/rest/networks/support', true, /^.\/(arcgisapi\/)?[^\/]+\.js$/));
// window.app.define('@wisdom-map/arcgismap/lib/arcgisapi/4.20/@arcgis/core/rest/query/support', require.context('../node_modules/@wisdom-map/arcgismap/lib/arcgisapi/4.20/@arcgis/core/rest/query/support', true, /^.\/(arcgisapi\/)?[^\/]+\.js$/));
// window.app.define('@wisdom-map/arcgismap/lib/arcgisapi/4.20/@arcgis/core/rest/support', require.context('../node_modules/@wisdom-map/arcgismap/lib/arcgisapi/4.20/@arcgis/core/rest/support', true, /^.\/(arcgisapi\/)?[^\/]+\.js$/));

// window.app.define('@wisdom-map/arcgismap/lib/arcgisapi/4.20/@arcgis/core/smartMapping/heuristics', require.context('../node_modules/@wisdom-map/arcgismap/lib/arcgisapi/4.20/@arcgis/core/smartMapping/heuristics', true, /^.\/(arcgisapi\/)?[^\/]+\.js$/));
// window.app.define('@wisdom-map/arcgismap/lib/arcgisapi/4.20/@arcgis/core/smartMapping/labels', require.context('../node_modules/@wisdom-map/arcgismap/lib/arcgisapi/4.20/@arcgis/core/smartMapping/labels', true, /^.\/(arcgisapi\/)?[^\/]+\.js$/));
// window.app.define('@wisdom-map/arcgismap/lib/arcgisapi/4.20/@arcgis/core/smartMapping/popup', require.context('../node_modules/@wisdom-map/arcgismap/lib/arcgisapi/4.20/@arcgis/core/smartMapping/popup', true, /^.\/(arcgisapi\/)?[^\/]+\.js$/));

// window.app.define('@wisdom-map/arcgismap/lib/arcgisapi/4.20/@arcgis/core/smartMapping/raster', require.context('../node_modules/@wisdom-map/arcgismap/lib/arcgisapi/4.20/@arcgis/core/smartMapping/raster', true, /^.\/(arcgisapi\/)?[^\/]+\.js$/));
// window.app.define('@wisdom-map/arcgismap/lib/arcgisapi/4.20/@arcgis/core/smartMapping/raster/renderers', require.context('../node_modules/@wisdom-map/arcgismap/lib/arcgisapi/4.20/@arcgis/core/smartMapping/raster/renderers', true, /^.\/(arcgisapi\/)?[^\/]+\.js$/));
// window.app.define('@wisdom-map/arcgismap/lib/arcgisapi/4.20/@arcgis/core/smartMapping/raster/support', require.context('../node_modules/@wisdom-map/arcgismap/lib/arcgisapi/4.20/@arcgis/core/smartMapping/raster/support', true, /^.\/(arcgisapi\/)?[^\/]+\.js$/));
// window.app.define('@wisdom-map/arcgismap/lib/arcgisapi/4.20/@arcgis/core/smartMapping/renderers', require.context('../node_modules/@wisdom-map/arcgismap/lib/arcgisapi/4.20/@arcgis/core/smartMapping/renderers', true, /^.\/(arcgisapi\/)?[^\/]+\.js$/));

// window.app.define('@wisdom-map/arcgismap/lib/arcgisapi/4.20/@arcgis/core/smartMapping/statistics', require.context('../node_modules/@wisdom-map/arcgismap/lib/arcgisapi/4.20/@arcgis/core/smartMapping/statistics', true, /^.\/(arcgisapi\/)?[^\/]+\.js$/));
// window.app.define('@wisdom-map/arcgismap/lib/arcgisapi/4.20/@arcgis/core/smartMapping/statistics/support', require.context('../node_modules/@wisdom-map/arcgismap/lib/arcgisapi/4.20/@arcgis/core/smartMapping/statistics/support', true, /^.\/(arcgisapi\/)?[^\/]+\.js$/));

// window.app.define('@wisdom-map/arcgismap/lib/arcgisapi/4.20/@arcgis/core/smartMapping/symbology', require.context('../node_modules/@wisdom-map/arcgismap/lib/arcgisapi/4.20/@arcgis/core/smartMapping/symbology', true, /^.\/(arcgisapi\/)?[^\/]+\.js$/));
// window.app.define('@wisdom-map/arcgismap/lib/arcgisapi/4.20/@arcgis/core/smartMapping/symbology/support', require.context('../node_modules/@wisdom-map/arcgismap/lib/arcgisapi/4.20/@arcgis/core/smartMapping/symbology/support', true, /^.\/(arcgisapi\/)?[^\/]+\.js$/));


// window.app.define('@wisdom-map/arcgismap/lib/arcgisapi/4.20/@arcgis/core/support', require.context('../node_modules/@wisdom-map/arcgismap/lib/arcgisapi/4.20/@arcgis/core/support', true, /^.\/(arcgisapi\/)?[^\/]+\.js$/));
// window.app.define('@wisdom-map/arcgismap/lib/arcgisapi/4.20/@arcgis/core/support/actions', require.context('../node_modules/@wisdom-map/arcgismap/lib/arcgisapi/4.20/@arcgis/core/support/actions', true, /^.\/(arcgisapi\/)?[^\/]+\.js$/));

// window.app.define('@wisdom-map/arcgismap/lib/arcgisapi/4.20/@arcgis/core/symbols', require.context('../node_modules/@wisdom-map/arcgismap/lib/arcgisapi/4.20/@arcgis/core/symbols', true, /^.\/(arcgisapi\/)?[^\/]+\.js$/));
// window.app.define('@wisdom-map/arcgismap/lib/arcgisapi/4.20/@arcgis/core/symbols/callouts', require.context('../node_modules/@wisdom-map/arcgismap/lib/arcgisapi/4.20/@arcgis/core/symbols/callouts', true, /^.\/(arcgisapi\/)?[^\/]+\.js$/));
// window.app.define('@wisdom-map/arcgismap/lib/arcgisapi/4.20/@arcgis/core/symbols/edges', require.context('../node_modules/@wisdom-map/arcgismap/lib/arcgisapi/4.20/@arcgis/core/symbols/edges', true, /^.\/(arcgisapi\/)?[^\/]+\.js$/));
// window.app.define('@wisdom-map/arcgismap/lib/arcgisapi/4.20/@arcgis/core/symbols/patterns', require.context('../node_modules/@wisdom-map/arcgismap/lib/arcgisapi/4.20/@arcgis/core/symbols/patterns', true, /^.\/(arcgisapi\/)?[^\/]+\.js$/));
// window.app.define('@wisdom-map/arcgismap/lib/arcgisapi/4.20/@arcgis/core/symbols/support', require.context('../node_modules/@wisdom-map/arcgismap/lib/arcgisapi/4.20/@arcgis/core/symbols/support', true, /^.\/(arcgisapi\/)?[^\/]+\.js$/));


// window.app.define('@wisdom-map/arcgismap/lib/arcgisapi/4.20/@arcgis/core/tasks', require.context('../node_modules/@wisdom-map/arcgismap/lib/arcgisapi/4.20/@arcgis/core/tasks', true, /^.\/(arcgisapi\/)?[^\/]+\.js$/));
// window.app.define('@wisdom-map/arcgismap/lib/arcgisapi/4.20/@arcgis/core/tasks/support', require.context('../node_modules/@wisdom-map/arcgismap/lib/arcgisapi/4.20/@arcgis/core/tasks/support', true, /^.\/(arcgisapi\/)?[^\/]+\.js$/));


// window.app.define('@wisdom-map/arcgismap/lib/arcgisapi/4.20/@arcgis/core/views', require.context('../node_modules/@wisdom-map/arcgismap/lib/arcgisapi/4.20/@arcgis/core/views', true, /^.\/(arcgisapi\/)?[^\/]+\.js$/));
// window.app.define('@wisdom-map/arcgismap/lib/arcgisapi/4.20/@arcgis/core/views/2d', require.context('../node_modules/@wisdom-map/arcgismap/lib/arcgisapi/4.20/@arcgis/core/views/2d', true, /^.\/(arcgisapi\/)?[^\/]+\.js$/));
// window.app.define('@wisdom-map/arcgismap/lib/arcgisapi/4.20/@arcgis/core/views/2d/layers', require.context('../node_modules/@wisdom-map/arcgismap/lib/arcgisapi/4.20/@arcgis/core/views/2d/layers', true, /^.\/(arcgisapi\/)?[^\/]+\.js$/));
// window.app.define('@wisdom-map/arcgismap/lib/arcgisapi/4.20/@arcgis/core/views/3d', require.context('../node_modules/@wisdom-map/arcgismap/lib/arcgisapi/4.20/@arcgis/core/views/3d', true, /^.\/(arcgisapi\/)?[^\/]+\.js$/));
// window.app.define('@wisdom-map/arcgismap/lib/arcgisapi/4.20/@arcgis/core/views/3d/support', require.context('../node_modules/@wisdom-map/arcgismap/lib/arcgisapi/4.20/@arcgis/core/views/3d/support', true, /^.\/(arcgisapi\/)?[^\/]+\.js$/));
// window.app.define('@wisdom-map/arcgismap/lib/arcgisapi/4.20/@arcgis/core/views/draw', require.context('../node_modules/@wisdom-map/arcgismap/lib/arcgisapi/4.20/@arcgis/core/views/draw', true, /^.\/(arcgisapi\/)?[^\/]+\.js$/));

// window.app.define('@wisdom-map/arcgismap/lib/arcgisapi/4.20/@arcgis/core/views/input', require.context('../node_modules/@wisdom-map/arcgismap/lib/arcgisapi/4.20/@arcgis/core/views/input', true, /^.\/(arcgisapi\/)?[^\/]+\.js$/));
// window.app.define('@wisdom-map/arcgismap/lib/arcgisapi/4.20/@arcgis/core/views/input/gamepad', require.context('../node_modules/@wisdom-map/arcgismap/lib/arcgisapi/4.20/@arcgis/core/views/input/gamepad', true, /^.\/(arcgisapi\/)?[^\/]+\.js$/));

// window.app.define('@wisdom-map/arcgismap/lib/arcgisapi/4.20/@arcgis/core/views/interactive/snapping', require.context('../node_modules/@wisdom-map/arcgismap/lib/arcgisapi/4.20/@arcgis/core/views/interactive/snapping', true, /^.\/(arcgisapi\/)?[^\/]+\.js$/));

// window.app.define('@wisdom-map/arcgismap/lib/arcgisapi/4.20/@arcgis/core/views/layers', require.context('../node_modules/@wisdom-map/arcgismap/lib/arcgisapi/4.20/@arcgis/core/views/layers', true, /^.\/(arcgisapi\/)?[^\/]+\.js$/));
// window.app.define('@wisdom-map/arcgismap/lib/arcgisapi/4.20/@arcgis/core/views/layers/support', require.context('../node_modules/@wisdom-map/arcgismap/lib/arcgisapi/4.20/@arcgis/core/views/layers/support', true, /^.\/(arcgisapi\/)?[^\/]+\.js$/));


// window.app.define('@wisdom-map/arcgismap/lib/arcgisapi/4.20/@arcgis/core/views/navigation', require.context('../node_modules/@wisdom-map/arcgismap/lib/arcgisapi/4.20/@arcgis/core/views/navigation', true, /^.\/(arcgisapi\/)?[^\/]+\.js$/));
// window.app.define('@wisdom-map/arcgismap/lib/arcgisapi/4.20/@arcgis/core/views/navigation/gamepad', require.context('../node_modules/@wisdom-map/arcgismap/lib/arcgisapi/4.20/@arcgis/core/views/navigation/gamepad', true, /^.\/(arcgisapi\/)?[^\/]+\.js$/));

// window.app.define('@wisdom-map/arcgismap/lib/arcgisapi/4.20/@arcgis/core/views/support', require.context('../node_modules/@wisdom-map/arcgismap/lib/arcgisapi/4.20/@arcgis/core/views/support', true, /^.\/(arcgisapi\/)?[^\/]+\.js$/));

// window.app.define('@wisdom-map/arcgismap/lib/arcgisapi/4.20/@arcgis/core/views/ui', require.context('../node_modules/@wisdom-map/arcgismap/lib/arcgisapi/4.20/@arcgis/core/views/ui', true, /^.\/(arcgisapi\/)?[^\/]+\.js$/));

// window.app.define('@wisdom-map/arcgismap/lib/arcgisapi/4.20/@arcgis/core/webdoc/applicationProperties', require.context('../node_modules/@wisdom-map/arcgismap/lib/arcgisapi/4.20/@arcgis/core/webdoc/applicationProperties', true, /^.\/(arcgisapi\/)?[^\/]+\.js$/));

// window.app.define('@wisdom-map/arcgismap/lib/arcgisapi/4.20/@arcgis/core/webmap', require.context('../node_modules/@wisdom-map/arcgismap/lib/arcgisapi/4.20/@arcgis/core/webmap', true, /^.\/(arcgisapi\/)?[^\/]+\.js$/));
// window.app.define('@wisdom-map/arcgismap/lib/arcgisapi/4.20/@arcgis/core/webmap/background', require.context('../node_modules/@wisdom-map/arcgismap/lib/arcgisapi/4.20/@arcgis/core/webmap/background', true, /^.\/(arcgisapi\/)?[^\/]+\.js$/));


// window.app.define('@wisdom-map/arcgismap/lib/arcgisapi/4.20/@arcgis/core/webscene', require.context('../node_modules/@wisdom-map/arcgismap/lib/arcgisapi/4.20/@arcgis/core/webscene', true, /^.\/(arcgisapi\/)?[^\/]+\.js$/));
// window.app.define('@wisdom-map/arcgismap/lib/arcgisapi/4.20/@arcgis/core/webscene/background', require.context('../node_modules/@wisdom-map/arcgismap/lib/arcgisapi/4.20/@arcgis/core/webscene/background', true, /^.\/(arcgisapi\/)?[^\/]+\.js$/));

// window.app.define('@wisdom-map/arcgismap/lib/arcgisapi/4.20/@arcgis/core/widgets', require.context('../node_modules/@wisdom-map/arcgismap/lib/arcgisapi/4.20/@arcgis/core/widgets', true, /^.\/(arcgisapi\/)?[^\/]+\.js$/));

// window.app.define('@wisdom-map/arcgismap/lib/arcgisapi/4.20/@arcgis/core/widgets/AreaMeasurement2D', require.context('../node_modules/@wisdom-map/arcgismap/lib/arcgisapi/4.20/@arcgis/core/widgets/AreaMeasurement2D', true, /^.\/(arcgisapi\/)?[^\/]+\.js$/));
// window.app.define('@wisdom-map/arcgismap/lib/arcgisapi/4.20/@arcgis/core/widgets/AreaMeasurement3D', require.context('../node_modules/@wisdom-map/arcgismap/lib/arcgisapi/4.20/@arcgis/core/widgets/AreaMeasurement3D', true, /^.\/(arcgisapi\/)?[^\/]+\.js$/));
// window.app.define('@wisdom-map/arcgismap/lib/arcgisapi/4.20/@arcgis/core/widgets/Attachments', require.context('../node_modules/@wisdom-map/arcgismap/lib/arcgisapi/4.20/@arcgis/core/widgets/Attachments', true, /^.\/(arcgisapi\/)?[^\/]+\.js$/));
// window.app.define('@wisdom-map/arcgismap/lib/arcgisapi/4.20/@arcgis/core/widgets/Attribution', require.context('../node_modules/@wisdom-map/arcgismap/lib/arcgisapi/4.20/@arcgis/core/widgets/Attribution', true, /^.\/(arcgisapi\/)?[^\/]+\.js$/));
// window.app.define('@wisdom-map/arcgismap/lib/arcgisapi/4.20/@arcgis/core/widgets/BasemapGallery', require.context('../node_modules/@wisdom-map/arcgismap/lib/arcgisapi/4.20/@arcgis/core/widgets/BasemapGallery', true, /^.\/(arcgisapi\/)?[^\/]+\.js$/));
// window.app.define('@wisdom-map/arcgismap/lib/arcgisapi/4.20/@arcgis/core/widgets/BasemapGallery/support', require.context('../node_modules/@wisdom-map/arcgismap/lib/arcgisapi/4.20/@arcgis/core/widgets/BasemapGallery/support', true, /^.\/(arcgisapi\/)?[^\/]+\.js$/));

// window.app.define('@wisdom-map/arcgismap/lib/arcgisapi/4.20/@arcgis/core/widgets/BasemapLayerList', require.context('../node_modules/@wisdom-map/arcgismap/lib/arcgisapi/4.20/@arcgis/core/widgets/BasemapLayerList', true, /^.\/(arcgisapi\/)?[^\/]+\.js$/));
// window.app.define('@wisdom-map/arcgismap/lib/arcgisapi/4.20/@arcgis/core/widgets/BasemapToggle', require.context('../node_modules/@wisdom-map/arcgismap/lib/arcgisapi/4.20/@arcgis/core/widgets/BasemapToggle', true, /^.\/(arcgisapi\/)?[^\/]+\.js$/));
// window.app.define('@wisdom-map/arcgismap/lib/arcgisapi/4.20/@arcgis/core/widgets/Bookmarks', require.context('../node_modules/@wisdom-map/arcgismap/lib/arcgisapi/4.20/@arcgis/core/widgets/Bookmarks', true, /^.\/(arcgisapi\/)?[^\/]+\.js$/));
// window.app.define('@wisdom-map/arcgismap/lib/arcgisapi/4.20/@arcgis/core/widgets/BuildingExplorer', require.context('../node_modules/@wisdom-map/arcgismap/lib/arcgisapi/4.20/@arcgis/core/widgets/BuildingExplorer', true, /^.\/(arcgisapi\/)?[^\/]+\.js$/));
// window.app.define('@wisdom-map/arcgismap/lib/arcgisapi/4.20/@arcgis/core/widgets/Compass', require.context('../node_modules/@wisdom-map/arcgismap/lib/arcgisapi/4.20/@arcgis/core/widgets/Compass', true, /^.\/(arcgisapi\/)?[^\/]+\.js$/));
// window.app.define('@wisdom-map/arcgismap/lib/arcgisapi/4.20/@arcgis/core/widgets/CoordinateConversion', require.context('../node_modules/@wisdom-map/arcgismap/lib/arcgisapi/4.20/@arcgis/core/widgets/CoordinateConversion', true, /^.\/(arcgisapi\/)?[^\/]+\.js$/));
// window.app.define('@wisdom-map/arcgismap/lib/arcgisapi/4.20/@arcgis/core/widgets/CoordinateConversion/support', require.context('../node_modules/@wisdom-map/arcgismap/lib/arcgisapi/4.20/@arcgis/core/widgets/CoordinateConversion/support', true, /^.\/(arcgisapi\/)?[^\/]+\.js$/));

// window.app.define('@wisdom-map/arcgismap/lib/arcgisapi/4.20/@arcgis/core/widgets/Daylight', require.context('../node_modules/@wisdom-map/arcgismap/lib/arcgisapi/4.20/@arcgis/core/widgets/Daylight', true, /^.\/(arcgisapi\/)?[^\/]+\.js$/));
// window.app.define('@wisdom-map/arcgismap/lib/arcgisapi/4.20/@arcgis/core/widgets/Directions', require.context('../node_modules/@wisdom-map/arcgismap/lib/arcgisapi/4.20/@arcgis/core/widgets/Directions', true, /^.\/(arcgisapi\/)?[^\/]+\.js$/));
// window.app.define('@wisdom-map/arcgismap/lib/arcgisapi/4.20/@arcgis/core/widgets/DirectLineMeasurement3D', require.context('../node_modules/@wisdom-map/arcgismap/lib/arcgisapi/4.20/@arcgis/core/widgets/DirectLineMeasurement3D', true, /^.\/(arcgisapi\/)?[^\/]+\.js$/));
// window.app.define('@wisdom-map/arcgismap/lib/arcgisapi/4.20/@arcgis/core/widgets/DistanceMeasurement2D', require.context('../node_modules/@wisdom-map/arcgismap/lib/arcgisapi/4.20/@arcgis/core/widgets/DistanceMeasurement2D', true, /^.\/(arcgisapi\/)?[^\/]+\.js$/));
// window.app.define('@wisdom-map/arcgismap/lib/arcgisapi/4.20/@arcgis/core/widgets/Editor', require.context('../node_modules/@wisdom-map/arcgismap/lib/arcgisapi/4.20/@arcgis/core/widgets/Editor', true, /^.\/(arcgisapi\/)?[^\/]+\.js$/));
// window.app.define('@wisdom-map/arcgismap/lib/arcgisapi/4.20/@arcgis/core/widgets/ElevationProfile', require.context('../node_modules/@wisdom-map/arcgismap/lib/arcgisapi/4.20/@arcgis/core/widgets/ElevationProfile', true, /^.\/(arcgisapi\/)?[^\/]+\.js$/));
// window.app.define('@wisdom-map/arcgismap/lib/arcgisapi/4.20/@arcgis/core/widgets/Expand', require.context('../node_modules/@wisdom-map/arcgismap/lib/arcgisapi/4.20/@arcgis/core/widgets/Expand', true, /^.\/(arcgisapi\/)?[^\/]+\.js$/));
// window.app.define('@wisdom-map/arcgismap/lib/arcgisapi/4.20/@arcgis/core/widgets/Feature', require.context('../node_modules/@wisdom-map/arcgismap/lib/arcgisapi/4.20/@arcgis/core/widgets/Feature', true, /^.\/(arcgisapi\/)?[^\/]+\.js$/));
// window.app.define('@wisdom-map/arcgismap/lib/arcgisapi/4.20/@arcgis/core/widgets/FeatureForm', require.context('../node_modules/@wisdom-map/arcgismap/lib/arcgisapi/4.20/@arcgis/core/widgets/FeatureForm', true, /^.\/(arcgisapi\/)?[^\/]+\.js$/));
// window.app.define('@wisdom-map/arcgismap/lib/arcgisapi/4.20/@arcgis/core/widgets/FeatureTable', require.context('../node_modules/@wisdom-map/arcgismap/lib/arcgisapi/4.20/@arcgis/core/widgets/FeatureTable', true, /^.\/(arcgisapi\/)?[^\/]+\.js$/));
// window.app.define('@wisdom-map/arcgismap/lib/arcgisapi/4.20/@arcgis/core/widgets/FeatureTable/Grid/support', require.context('../node_modules/@wisdom-map/arcgismap/lib/arcgisapi/4.20/@arcgis/core/widgets/FeatureTable/Grid/support', true, /^.\/(arcgisapi\/)?[^\/]+\.js$/));


// window.app.define('@wisdom-map/arcgismap/lib/arcgisapi/4.20/@arcgis/core/widgets/FeatureTemplates', require.context('../node_modules/@wisdom-map/arcgismap/lib/arcgisapi/4.20/@arcgis/core/widgets/FeatureTemplates', true, /^.\/(arcgisapi\/)?[^\/]+\.js$/));
// window.app.define('@wisdom-map/arcgismap/lib/arcgisapi/4.20/@arcgis/core/widgets/FloorFilter', require.context('../node_modules/@wisdom-map/arcgismap/lib/arcgisapi/4.20/@arcgis/core/widgets/FloorFilter', true, /^.\/(arcgisapi\/)?[^\/]+\.js$/));
// window.app.define('@wisdom-map/arcgismap/lib/arcgisapi/4.20/@arcgis/core/widgets/Fullscreen', require.context('../node_modules/@wisdom-map/arcgismap/lib/arcgisapi/4.20/@arcgis/core/widgets/Fullscreen', true, /^.\/(arcgisapi\/)?[^\/]+\.js$/));
// window.app.define('@wisdom-map/arcgismap/lib/arcgisapi/4.20/@arcgis/core/widgets/Histogram', require.context('../node_modules/@wisdom-map/arcgismap/lib/arcgisapi/4.20/@arcgis/core/widgets/Histogram', true, /^.\/(arcgisapi\/)?[^\/]+\.js$/));
// window.app.define('@wisdom-map/arcgismap/lib/arcgisapi/4.20/@arcgis/core/widgets/HistogramRangeSlider', require.context('../node_modules/@wisdom-map/arcgismap/lib/arcgisapi/4.20/@arcgis/core/widgets/HistogramRangeSlider', true, /^.\/(arcgisapi\/)?[^\/]+\.js$/));
// window.app.define('@wisdom-map/arcgismap/lib/arcgisapi/4.20/@arcgis/core/widgets/Home', require.context('../node_modules/@wisdom-map/arcgismap/lib/arcgisapi/4.20/@arcgis/core/widgets/Home', true, /^.\/(arcgisapi\/)?[^\/]+\.js$/));
// window.app.define('@wisdom-map/arcgismap/lib/arcgisapi/4.20/@arcgis/core/widgets/LayerList', require.context('../node_modules/@wisdom-map/arcgismap/lib/arcgisapi/4.20/@arcgis/core/widgets/LayerList', true, /^.\/(arcgisapi\/)?[^\/]+\.js$/));
// window.app.define('@wisdom-map/arcgismap/lib/arcgisapi/4.20/@arcgis/core/widgets/Legend', require.context('../node_modules/@wisdom-map/arcgismap/lib/arcgisapi/4.20/@arcgis/core/widgets/Legend', true, /^.\/(arcgisapi\/)?[^\/]+\.js$/));
// window.app.define('@wisdom-map/arcgismap/lib/arcgisapi/4.20/@arcgis/core/widgets/Legend/support', require.context('../node_modules/@wisdom-map/arcgismap/lib/arcgisapi/4.20/@arcgis/core/widgets/Legend/support', true, /^.\/(arcgisapi\/)?[^\/]+\.js$/));
// window.app.define('@wisdom-map/arcgismap/lib/arcgisapi/4.20/@arcgis/core/widgets/LineOfSight', require.context('../node_modules/@wisdom-map/arcgismap/lib/arcgisapi/4.20/@arcgis/core/widgets/LineOfSight', true, /^.\/(arcgisapi\/)?[^\/]+\.js$/));
// window.app.define('@wisdom-map/arcgismap/lib/arcgisapi/4.20/@arcgis/core/widgets/Locate', require.context('../node_modules/@wisdom-map/arcgismap/lib/arcgisapi/4.20/@arcgis/core/widgets/Locate', true, /^.\/(arcgisapi\/)?[^\/]+\.js$/));


// window.app.define('@wisdom-map/arcgismap/lib/arcgisapi/4.20/@arcgis/core/widgets/Measurement', require.context('../node_modules/@wisdom-map/arcgismap/lib/arcgisapi/4.20/@arcgis/core/widgets/Measurement', true, /^.\/(arcgisapi\/)?[^\/]+\.js$/));
// window.app.define('@wisdom-map/arcgismap/lib/arcgisapi/4.20/@arcgis/core/widgets/NavigationToggle', require.context('../node_modules/@wisdom-map/arcgismap/lib/arcgisapi/4.20/@arcgis/core/widgets/NavigationToggle', true, /^.\/(arcgisapi\/)?[^\/]+\.js$/));
// window.app.define('@wisdom-map/arcgismap/lib/arcgisapi/4.20/@arcgis/core/widgets/Popup', require.context('../node_modules/@wisdom-map/arcgismap/lib/arcgisapi/4.20/@arcgis/core/widgets/Popup', true, /^.\/(arcgisapi\/)?[^\/]+\.js$/));
// window.app.define('@wisdom-map/arcgismap/lib/arcgisapi/4.20/@arcgis/core/widgets/Print', require.context('../node_modules/@wisdom-map/arcgismap/lib/arcgisapi/4.20/@arcgis/core/widgets/Print', true, /^.\/(arcgisapi\/)?[^\/]+\.js$/));
// window.app.define('@wisdom-map/arcgismap/lib/arcgisapi/4.20/@arcgis/core/widgets/ScaleBar', require.context('../node_modules/@wisdom-map/arcgismap/lib/arcgisapi/4.20/@arcgis/core/widgets/ScaleBar', true, /^.\/(arcgisapi\/)?[^\/]+\.js$/));
// window.app.define('@wisdom-map/arcgismap/lib/arcgisapi/4.20/@arcgis/core/widgets/ScaleRangeSlider', require.context('../node_modules/@wisdom-map/arcgismap/lib/arcgisapi/4.20/@arcgis/core/widgets/ScaleRangeSlider', true, /^.\/(arcgisapi\/)?[^\/]+\.js$/));
// window.app.define('@wisdom-map/arcgismap/lib/arcgisapi/4.20/@arcgis/core/widgets/Search', require.context('../node_modules/@wisdom-map/arcgismap/lib/arcgisapi/4.20/@arcgis/core/widgets/Search', true, /^.\/(arcgisapi\/)?[^\/]+\.js$/));
// window.app.define('@wisdom-map/arcgismap/lib/arcgisapi/4.20/@arcgis/core/widgets/ShadowAccumulation', require.context('../node_modules/@wisdom-map/arcgismap/lib/arcgisapi/4.20/@arcgis/core/widgets/ShadowAccumulation', true, /^.\/(arcgisapi\/)?[^\/]+\.js$/));

// window.app.define('@wisdom-map/arcgismap/lib/arcgisapi/4.20/@arcgis/core/widgets/Sketch', require.context('../node_modules/@wisdom-map/arcgismap/lib/arcgisapi/4.20/@arcgis/core/widgets/Sketch', true, /^.\/(arcgisapi\/)?[^\/]+\.js$/));
// window.app.define('@wisdom-map/arcgismap/lib/arcgisapi/4.20/@arcgis/core/widgets/Slice', require.context('../node_modules/@wisdom-map/arcgismap/lib/arcgisapi/4.20/@arcgis/core/widgets/Slice', true, /^.\/(arcgisapi\/)?[^\/]+\.js$/));
// window.app.define('@wisdom-map/arcgismap/lib/arcgisapi/4.20/@arcgis/core/widgets/Slider', require.context('../node_modules/@wisdom-map/arcgismap/lib/arcgisapi/4.20/@arcgis/core/widgets/Slider', true, /^.\/(arcgisapi\/)?[^\/]+\.js$/));
// window.app.define('@wisdom-map/arcgismap/lib/arcgisapi/4.20/@arcgis/core/widgets/Spinner', require.context('../node_modules/@wisdom-map/arcgismap/lib/arcgisapi/4.20/@arcgis/core/widgets/Spinner', true, /^.\/(arcgisapi\/)?[^\/]+\.js$/));
// window.app.define('@wisdom-map/arcgismap/lib/arcgisapi/4.20/@arcgis/core/widgets/support', require.context('../node_modules/@wisdom-map/arcgismap/lib/arcgisapi/4.20/@arcgis/core/widgets/support', true, /^.\/(arcgisapi\/)?[^\/]+\.js$/));
// window.app.define('@wisdom-map/arcgismap/lib/arcgisapi/4.20/@arcgis/core/widgets/Swipe', require.context('../node_modules/@wisdom-map/arcgismap/lib/arcgisapi/4.20/@arcgis/core/widgets/Swipe', true, /^.\/(arcgisapi\/)?[^\/]+\.js$/));

// window.app.define('@wisdom-map/arcgismap/lib/arcgisapi/4.20/@arcgis/core/widgets/TableList', require.context('../node_modules/@wisdom-map/arcgismap/lib/arcgisapi/4.20/@arcgis/core/widgets/TableList', true, /^.\/(arcgisapi\/)?[^\/]+\.js$/));
// window.app.define('@wisdom-map/arcgismap/lib/arcgisapi/4.20/@arcgis/core/widgets/TimeSlider', require.context('../node_modules/@wisdom-map/arcgismap/lib/arcgisapi/4.20/@arcgis/core/widgets/TimeSlider', true, /^.\/(arcgisapi\/)?[^\/]+\.js$/));
// window.app.define('@wisdom-map/arcgismap/lib/arcgisapi/4.20/@arcgis/core/widgets/Track', require.context('../node_modules/@wisdom-map/arcgismap/lib/arcgisapi/4.20/@arcgis/core/widgets/Track', true, /^.\/(arcgisapi\/)?[^\/]+\.js$/));
// window.app.define('@wisdom-map/arcgismap/lib/arcgisapi/4.20/@arcgis/core/widgets/Zoom', require.context('../node_modules/@wisdom-map/arcgismap/lib/arcgisapi/4.20/@arcgis/core/widgets/Zoom', true, /^.\/(arcgisapi\/)?[^\/]+\.js$/));

// window.app.define('@wisdom-map/arcgismap/lib/arcgisapi/4.20/@arcgis/core/widgets/smartMapping', require.context('../node_modules/@wisdom-map/arcgismap/lib/arcgisapi/4.20/@arcgis/core/widgets/smartMapping', true, /^.\/(arcgisapi\/)?[^\/]+\.js$/));
// window.app.define('@wisdom-map/arcgismap/lib/arcgisapi/4.20/@arcgis/core/widgets/smartMapping/ClassedColorSlider', require.context('../node_modules/@wisdom-map/arcgismap/lib/arcgisapi/4.20/@arcgis/core/widgets/smartMapping/ClassedColorSlider', true, /^.\/(arcgisapi\/)?[^\/]+\.js$/));
// window.app.define('@wisdom-map/arcgismap/lib/arcgisapi/4.20/@arcgis/core/widgets/smartMapping/ClassedSizeSlider', require.context('../node_modules/@wisdom-map/arcgismap/lib/arcgisapi/4.20/@arcgis/core/widgets/smartMapping/ClassedSizeSlider', true, /^.\/(arcgisapi\/)?[^\/]+\.js$/));
// window.app.define('@wisdom-map/arcgismap/lib/arcgisapi/4.20/@arcgis/core/widgets/smartMapping/ColorSizeSlider', require.context('../node_modules/@wisdom-map/arcgismap/lib/arcgisapi/4.20/@arcgis/core/widgets/smartMapping/ColorSizeSlider', true, /^.\/(arcgisapi\/)?[^\/]+\.js$/));
// window.app.define('@wisdom-map/arcgismap/lib/arcgisapi/4.20/@arcgis/core/widgets/smartMapping/ColorSlider', require.context('../node_modules/@wisdom-map/arcgismap/lib/arcgisapi/4.20/@arcgis/core/widgets/smartMapping/ColorSlider', true, /^.\/(arcgisapi\/)?[^\/]+\.js$/));
// window.app.define('@wisdom-map/arcgismap/lib/arcgisapi/4.20/@arcgis/core/widgets/smartMapping/HeatmapSlider', require.context('../node_modules/@wisdom-map/arcgismap/lib/arcgisapi/4.20/@arcgis/core/widgets/smartMapping/HeatmapSlider', true, /^.\/(arcgisapi\/)?[^\/]+\.js$/));

// window.app.define('@wisdom-map/arcgismap/lib/arcgisapi/4.20/@arcgis/core/widgets/smartMapping/OpacitySlider', require.context('../node_modules/@wisdom-map/arcgismap/lib/arcgisapi/4.20/@arcgis/core/widgets/smartMapping/OpacitySlider', true, /^.\/(arcgisapi\/)?[^\/]+\.js$/));
// window.app.define('@wisdom-map/arcgismap/lib/arcgisapi/4.20/@arcgis/core/widgets/smartMapping/SizeSlider', require.context('../node_modules/@wisdom-map/arcgismap/lib/arcgisapi/4.20/@arcgis/core/widgets/smartMapping/SizeSlider', true, /^.\/(arcgisapi\/)?[^\/]+\.js$/));
// window.app.define('@wisdom-map/arcgismap/lib/arcgisapi/4.20/@arcgis/core/widgets/smartMapping/support', require.context('../node_modules/@wisdom-map/arcgismap/lib/arcgisapi/4.20/@arcgis/core/widgets/smartMapping/support', true, /^.\/(arcgisapi\/)?[^\/]+\.js$/));


window.app.define('@ant-design/pro-list', require.context('../node_modules/@ant-design/pro-list/lib', true, /^.\/(lib\/)?[^\/]+\.js$/), 'index.js');
window.app.define('antd', require.context('../node_modules/antd/es', true, /^.\/(es\/)?[^\/]+\.js$/), 'index.js');
// window.app.define("antd-es-affix-style", require.context("../node_modules/antd/es/affix/style", true, /^.\/(style\/)?[^\/]+.js$/), 'index.js')
//  window.app.define("antd-es-alert-style", require.context("../node_modules/antd/es/alert/style", true, /^.\/(style\/)?[^\/]+.js$/), 'index.js')
//  window.app.define("antd-es-anchor-style", require.context("../node_modules/antd/es/anchor/style", true, /^.\/(style\/)?[^\/]+.js$/), 'index.js')
//  window.app.define("antd-es-auto-complete-style", require.context("../node_modules/antd/es/auto-complete/style", true, /^.\/(style\/)?[^\/]+.js$/), 'index.js')
//  window.app.define("antd-es-avatar-style", require.context("../node_modules/antd/es/avatar/style", true, /^.\/(style\/)?[^\/]+.js$/), 'index.js')
//  window.app.define("antd-es-back-top-style", require.context("../node_modules/antd/es/back-top/style", true, /^.\/(style\/)?[^\/]+.js$/), 'index.js')
//  window.app.define("antd-es-badge-style", require.context("../node_modules/antd/es/badge/style", true, /^.\/(style\/)?[^\/]+.js$/), 'index.js')
//  window.app.define("antd-es-breadcrumb-style", require.context("../node_modules/antd/es/breadcrumb/style", true, /^.\/(style\/)?[^\/]+.js$/), 'index.js')
//  window.app.define("antd-es-button-style", require.context("../node_modules/antd/es/button/style", true, /^.\/(style\/)?[^\/]+.js$/), 'index.js')
//  window.app.define("antd-es-calendar-style", require.context("../node_modules/antd/es/calendar/style", true, /^.\/(style\/)?[^\/]+.js$/), 'index.js')
//  window.app.define("antd-es-card-style", require.context("../node_modules/antd/es/card/style", true, /^.\/(style\/)?[^\/]+.js$/), 'index.js')
//  window.app.define("antd-es-carousel-style", require.context("../node_modules/antd/es/carousel/style", true, /^.\/(style\/)?[^\/]+.js$/), 'index.js')
//  window.app.define("antd-es-cascader-style", require.context("../node_modules/antd/es/cascader/style", true, /^.\/(style\/)?[^\/]+.js$/), 'index.js')
//  window.app.define("antd-es-checkbox-style", require.context("../node_modules/antd/es/checkbox/style", true, /^.\/(style\/)?[^\/]+.js$/), 'index.js')
//  window.app.define("antd-es-col-style", require.context("../node_modules/antd/es/col/style", true, /^.\/(style\/)?[^\/]+.js$/), 'index.js')
//  window.app.define("antd-es-collapse-style", require.context("../node_modules/antd/es/collapse/style", true, /^.\/(style\/)?[^\/]+.js$/), 'index.js')
//  window.app.define("antd-es-comment-style", require.context("../node_modules/antd/es/comment/style", true, /^.\/(style\/)?[^\/]+.js$/), 'index.js')
//  window.app.define("antd-es-config-provider-style", require.context("../node_modules/antd/es/config-provider/style", true, /^.\/(style\/)?[^\/]+.js$/), 'index.js')
//  window.app.define("antd-es-date-picker-style", require.context("../node_modules/antd/es/date-picker/style", true, /^.\/(style\/)?[^\/]+.js$/), 'index.js')
//  window.app.define("antd-es-descriptions-style", require.context("../node_modules/antd/es/descriptions/style", true, /^.\/(style\/)?[^\/]+.js$/), 'index.js')
//  window.app.define("antd-es-divider-style", require.context("../node_modules/antd/es/divider/style", true, /^.\/(style\/)?[^\/]+.js$/), 'index.js')
//  window.app.define("antd-es-drawer-style", require.context("../node_modules/antd/es/drawer/style", true, /^.\/(style\/)?[^\/]+.js$/), 'index.js')
//  window.app.define("antd-es-dropdown-style", require.context("../node_modules/antd/es/dropdown/style", true, /^.\/(style\/)?[^\/]+.js$/), 'index.js')
//  window.app.define("antd-es-empty-style", require.context("../node_modules/antd/es/empty/style", true, /^.\/(style\/)?[^\/]+.js$/), 'index.js')
//  window.app.define("antd-es-form-style", require.context("../node_modules/antd/es/form/style", true, /^.\/(style\/)?[^\/]+.js$/), 'index.js')
//  window.app.define("antd-es-grid-style", require.context("../node_modules/antd/es/grid/style", true, /^.\/(style\/)?[^\/]+.js$/), 'index.js')
//  window.app.define("antd-es-icon-style", require.context("../node_modules/antd/es/icon/style", true, /^.\/(style\/)?[^\/]+.js$/), 'index.js')
//  window.app.define("antd-es-image-style", require.context("../node_modules/antd/es/image/style", true, /^.\/(style\/)?[^\/]+.js$/), 'index.js')
//  window.app.define("antd-es-input-style", require.context("../node_modules/antd/es/input/style", true, /^.\/(style\/)?[^\/]+.js$/), 'index.js')
//  window.app.define("antd-es-input-number-style", require.context("../node_modules/antd/es/input-number/style", true, /^.\/(style\/)?[^\/]+.js$/), 'index.js')
//  window.app.define("antd-es-layout-style", require.context("../node_modules/antd/es/layout/style", true, /^.\/(style\/)?[^\/]+.js$/), 'index.js')
//  window.app.define("antd-es-list-style", require.context("../node_modules/antd/es/list/style", true, /^.\/(style\/)?[^\/]+.js$/), 'index.js')
//  window.app.define("antd-es-locale-provider-style", require.context("../node_modules/antd/es/locale-provider/style", true, /^.\/(style\/)?[^\/]+.js$/), 'index.js')
//  window.app.define("antd-es-mentions-style", require.context("../node_modules/antd/es/mentions/style", true, /^.\/(style\/)?[^\/]+.js$/), 'index.js')
//  window.app.define("antd-es-menu-style", require.context("../node_modules/antd/es/menu/style", true, /^.\/(style\/)?[^\/]+.js$/), 'index.js')
//  window.app.define("antd-es-message-style", require.context("../node_modules/antd/es/message/style", true, /^.\/(style\/)?[^\/]+.js$/), 'index.js')
//  window.app.define("antd-es-modal-style", require.context("../node_modules/antd/es/modal/style", true, /^.\/(style\/)?[^\/]+.js$/), 'index.js')
//  window.app.define("antd-es-notification-style", require.context("../node_modules/antd/es/notification/style", true, /^.\/(style\/)?[^\/]+.js$/), 'index.js')
//  window.app.define("antd-es-page-header-style", require.context("../node_modules/antd/es/page-header/style", true, /^.\/(style\/)?[^\/]+.js$/), 'index.js')
//  window.app.define("antd-es-pagination-style", require.context("../node_modules/antd/es/pagination/style", true, /^.\/(style\/)?[^\/]+.js$/), 'index.js')
//  window.app.define("antd-es-popconfirm-style", require.context("../node_modules/antd/es/popconfirm/style", true, /^.\/(style\/)?[^\/]+.js$/), 'index.js')
//  window.app.define("antd-es-popover-style", require.context("../node_modules/antd/es/popover/style", true, /^.\/(style\/)?[^\/]+.js$/), 'index.js')
//  window.app.define("antd-es-progress-style", require.context("../node_modules/antd/es/progress/style", true, /^.\/(style\/)?[^\/]+.js$/), 'index.js')
//  window.app.define("antd-es-radio-style", require.context("../node_modules/antd/es/radio/style", true, /^.\/(style\/)?[^\/]+.js$/), 'index.js')
//  window.app.define("antd-es-rate-style", require.context("../node_modules/antd/es/rate/style", true, /^.\/(style\/)?[^\/]+.js$/), 'index.js')
//  window.app.define("antd-es-result-style", require.context("../node_modules/antd/es/result/style", true, /^.\/(style\/)?[^\/]+.js$/), 'index.js')
//  window.app.define("antd-es-row-style", require.context("../node_modules/antd/es/row/style", true, /^.\/(style\/)?[^\/]+.js$/), 'index.js')
//  window.app.define("antd-es-select-style", require.context("../node_modules/antd/es/select/style", true, /^.\/(style\/)?[^\/]+.js$/), 'index.js')
//  window.app.define("antd-es-skeleton-style", require.context("../node_modules/antd/es/skeleton/style", true, /^.\/(style\/)?[^\/]+.js$/), 'index.js')
//  window.app.define("antd-es-slider-style", require.context("../node_modules/antd/es/slider/style", true, /^.\/(style\/)?[^\/]+.js$/), 'index.js')
//  window.app.define("antd-es-space-style", require.context("../node_modules/antd/es/space/style", true, /^.\/(style\/)?[^\/]+.js$/), 'index.js')
//  window.app.define("antd-es-spin-style", require.context("../node_modules/antd/es/spin/style", true, /^.\/(style\/)?[^\/]+.js$/), 'index.js')
//  window.app.define("antd-es-statistic-style", require.context("../node_modules/antd/es/statistic/style", true, /^.\/(style\/)?[^\/]+.js$/), 'index.js')
//  window.app.define("antd-es-steps-style", require.context("../node_modules/antd/es/steps/style", true, /^.\/(style\/)?[^\/]+.js$/), 'index.js')
//  window.app.define("antd-es-switch-style", require.context("../node_modules/antd/es/switch/style", true, /^.\/(style\/)?[^\/]+.js$/), 'index.js')
//  window.app.define("antd-es-table-style", require.context("../node_modules/antd/es/table/style", true, /^.\/(style\/)?[^\/]+.js$/), 'index.js')
//  window.app.define("antd-es-tabs-style", require.context("../node_modules/antd/es/tabs/style", true, /^.\/(style\/)?[^\/]+.js$/), 'index.js')
//  window.app.define("antd-es-tag-style", require.context("../node_modules/antd/es/tag/style", true, /^.\/(style\/)?[^\/]+.js$/), 'index.js')
//  window.app.define("antd-es-time-picker-style", require.context("../node_modules/antd/es/time-picker/style", true, /^.\/(style\/)?[^\/]+.js$/), 'index.js')
//  window.app.define("antd-es-timeline-style", require.context("../node_modules/antd/es/timeline/style", true, /^.\/(style\/)?[^\/]+.js$/), 'index.js')
//  window.app.define("antd-es-tooltip-style", require.context("../node_modules/antd/es/tooltip/style", true, /^.\/(style\/)?[^\/]+.js$/), 'index.js')
//  window.app.define("antd-es-transfer-style", require.context("../node_modules/antd/es/transfer/style", true, /^.\/(style\/)?[^\/]+.js$/), 'index.js')
//  window.app.define("antd-es-tree-style", require.context("../node_modules/antd/es/tree/style", true, /^.\/(style\/)?[^\/]+.js$/), 'index.js')
//  window.app.define("antd-es-tree-select-style", require.context("../node_modules/antd/es/tree-select/style", true, /^.\/(style\/)?[^\/]+.js$/), 'index.js')
//  window.app.define("antd-es-typography-style", require.context("../node_modules/antd/es/typography/style", true, /^.\/(style\/)?[^\/]+.js$/), 'index.js')
//  window.app.define("antd-es-upload-style", require.context("../node_modules/antd/es/upload/style", true, /^.\/(style\/)?[^\/]+.js$/), 'index.js')
//  window.app.define("antd-es-version-style", require.context("../node_modules/antd/es/version/style", true, /^.\/(style\/)?[^\/]+.js$/), 'index.js')
//  window.app.define("antd-es-locale-zh_CN", require.context("../node_modules/antd/es/locale", true, /^.\/(style\/)?[^\/]+.js$/))
// window.app.define('@wisdom-map/arcgismap/lib/arcgisapi/4.20/@arcgis/core/widgets/TableList', require.context('../node_modules/@wisdom-map/arcgismap/lib/arcgisapi/4.20/@arcgis/core/widgets/TableList', true, /^.\/(arcgisapi\/)?[^\/]+\.js$/));
// window.app.define('antd-style', require.context('../node_modules/antd/es/button/style', true, /^.\/(style\/)?[^\/]+\.js$/));
window.app.define('classnames', require.context('classnames', true, /^.\/index\.js$/), 'index.js');
window.app.define('@ant-design/icons', require.context('../node_modules/@ant-design/icons/lib', true, /^.\/(lib\/)?[^\/]+\.js$/), 'index.js');
window.app.define('@ant-design/pro-utils', require.context('../node_modules/@ant-design/pro-utils/lib', true, /^.\/(lib\/)?[^\/]+\.js$/), 'index.js');
window.app.define('@ant-design/pro-layout', require.context('../node_modules/@ant-design/pro-layout/lib', true, /^.\/(lib\/)?[^\/]+\.js$/), 'index.js');
window.app.define('@ant-design/pro-table', require.context('../node_modules/@ant-design/pro-table/lib', true, /^.\/(lib\/)?[^\/]+\.js$/), 'index.js');
window.app.define('@ant-design/pro-form', require.context('../node_modules/@ant-design/pro-form/lib', true, /^.\/(lib\/)?[^\/]+\.js$/), 'index.js');
window.app.define('@ant-design/pro-provider', require.context('../node_modules/@ant-design/pro-provider/lib', true, /^.\/(lib\/)?[^\/]+\.js$/), 'index.js');
window.app.define('pinyin-match', require.context('../node_modules/pinyin-match/lib', true, /^.\/(lib\/)?[^\/]+\.js$/), 'main.js');
window.app.define('react-intl', require.context('../node_modules/react-intl/lib', true, /^.\/(lib\/)?[^\/]+\.js$/), 'index.js');
window.app.define('moment', require.context('moment', true, /^.\/moment\.js$/), 'moment.js');

// window.app.define('rc-align', require.context('../node_modules/rc-align/lib', true, /^.\/(lib\/)?[^\/]+\.js$/), 'index.js');
// window.app.define('rc-cascader', require.context('../node_modules/rc-cascader/lib', true, /^.\/(lib\/)?[^\/]+\.js$/), 'index.js');
// window.app.define('rc-checkbox', require.context('../node_modules/rc-checkbox/lib', true, /^.\/(lib\/)?[^\/]+\.js$/), 'index.js');
// window.app.define('rc-collapse', require.context('../node_modules/rc-collapse/lib', true, /^.\/(lib\/)?[^\/]+\.js$/), 'index.js')
// window.app.define('rc-dialog', require.context('../node_modules/rc-dialog/lib', true, /^.\/(lib\/)?[^\/]+\.js$/), 'index.js');
// window.app.define('rc-drawer', require.context('../node_modules/rc-drawer/lib', true, /^.\/(lib\/)?[^\/]+\.js$/), 'index.js');
// window.app.define('rc-dropdown', require.context('../node_modules/rc-dropdown/lib', true, /^.\/(lib\/)?[^\/]+\.js$/), 'index.js');
// window.app.define('rc-field-form', require.context('../node_modules/rc-field-form/lib', true, /^.\/(lib\/)?[^\/]+\.js$/), 'index.js');
// window.app.define('rc-image', require.context('../node_modules/rc-image/lib', true, /^.\/(lib\/)?[^\/]+\.js$/), 'index.js');
// window.app.define('rc-input-number', require.context('../node_modules/rc-input-number/lib', true, /^.\/(lib\/)?[^\/]+\.js$/), 'index.js');
// window.app.define('rc-mentions', require.context('../node_modules/rc-mentions/lib', true, /^.\/(lib\/)?[^\/]+\.js$/), 'index.js');
// window.app.define('rc-menu', require.context('../node_modules/rc-menu/lib', true, /^.\/(lib\/)?[^\/]+\.js$/), 'index.js');
// window.app.define('rc-motion', require.context('../node_modules/rc-motion/lib', true, /^.\/(lib\/)?[^\/]+\.js$/), 'index.js');
// window.app.define('rc-notification', require.context('../node_modules/rc-notification/lib', true, /^.\/(lib\/)?[^\/]+\.js$/), 'index.js');
// window.app.define('rc-overflow', require.context('../node_modules/rc-overflow/lib', true, /^.\/(lib\/)?[^\/]+\.js$/), 'index.js');
// window.app.define('rc-pagination', require.context('../node_modules/rc-pagination/lib', true, /^.\/(lib\/)?[^\/]+\.js$/), 'index.js');
// window.app.define('rc-picker', require.context('../node_modules/rc-picker/lib', true, /^.\/(lib\/)?[^\/]+\.js$/), 'index.js');
// window.app.define('rc-progress', require.context('../node_modules/rc-progress/lib', true, /^.\/(lib\/)?[^\/]+\.js$/), 'index.js');
// window.app.define('rc-rate', require.context('../node_modules/rc-rate/lib', true, /^.\/(lib\/)?[^\/]+\.js$/), 'index.js');
// window.app.define('rc-resize-observer', require.context('../node_modules/rc-resize-observer/lib', true, /^.\/(lib\/)?[^\/]+\.js$/), 'index.js');
// window.app.define('rc-select', require.context('../node_modules/rc-select/lib', true, /^.\/(lib\/)?[^\/]+\.js$/), 'index.js');
// window.app.define('rc-slider', require.context('../node_modules/rc-slider/lib', true, /^.\/(lib\/)?[^\/]+\.js$/), 'index.js');
// window.app.define('rc-steps', require.context('../node_modules/rc-steps/lib', true, /^.\/(lib\/)?[^\/]+\.js$/), 'index.js');
// window.app.define('rc-switch', require.context('../node_modules/rc-switch/lib', true, /^.\/(lib\/)?[^\/]+\.js$/), 'index.js');
// window.app.define('rc-table', require.context('../node_modules/rc-table/lib', true, /^.\/(lib\/)?[^\/]+\.js$/), 'index.js');
// window.app.define('rc-tabs', require.context('../node_modules/rc-tabs/lib', true, /^.\/(lib\/)?[^\/]+\.js$/), 'index.js');
// window.app.define('rc-textarea', require.context('../node_modules/rc-textarea/lib', true, /^.\/(lib\/)?[^\/]+\.js$/), 'index.js');
// window.app.define('rc-tooltip', require.context('../node_modules/rc-tooltip/lib', true, /^.\/(lib\/)?[^\/]+\.js$/), 'index.js');
// window.app.define('rc-tree', require.context('../node_modules/rc-tree/lib', true, /^.\/(lib\/)?[^\/]+\.js$/), 'index.js');
// window.app.define('rc-tree-select', require.context('../node_modules/rc-tree-select/lib', true, /^.\/(lib\/)?[^\/]+\.js$/), 'index.js');
// window.app.define('rc-trigger', require.context('../node_modules/rc-trigger/lib', true, /^.\/(lib\/)?[^\/]+\.js$/), 'index.js');
// window.app.define('rc-upload', require.context('../node_modules/rc-upload/lib', true, /^.\/(lib\/)?[^\/]+\.js$/), 'index.js');
// window.app.define('rc-virtual-list', require.context('../node_modules/rc-virtual-list/lib', true, /^.\/(lib\/)?[^\/]+\.js$/), 'index.js');
